==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/ExclusionGroupAssignmentTarget.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import odata.msgraph.client.beta.enums.DeviceAndAppManagementAssignmentFilterType;


/**
 * <i>“Represents a group that should be excluded from an assignment.”</i>
 */@JsonPropertyOrder({
    "@odata.type"})
@JsonInclude(Include.NON_NULL)
public class ExclusionGroupAssignmentTarget extends GroupAssignmentTarget implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    protected ExclusionGroupAssignmentTarget() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.exclusionGroupAssignmentTarget";
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderExclusionGroupAssignmentTarget() {
        return new Builder();
    }

    public static final class Builder {
        private String deviceAndAppManagementAssignmentFilterId;
        private DeviceAndAppManagementAssignmentFilterType deviceAndAppManagementAssignmentFilterType;
        private String groupId;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder deviceAndAppManagementAssignmentFilterId(String deviceAndAppManagementAssignmentFilterId) {
            this.deviceAndAppManagementAssignmentFilterId = deviceAndAppManagementAssignmentFilterId;
            this.changedFields = changedFields.add("deviceAndAppManagementAssignmentFilterId");
            return this;
        }

        public Builder deviceAndAppManagementAssignmentFilterType(DeviceAndAppManagementAssignmentFilterType deviceAndAppManagementAssignmentFilterType) {
            this.deviceAndAppManagementAssignmentFilterType = deviceAndAppManagementAssignmentFilterType;
            this.changedFields = changedFields.add("deviceAndAppManagementAssignmentFilterType");
            return this;
        }

        public Builder groupId(String groupId) {
            this.groupId = groupId;
            this.changedFields = changedFields.add("groupId");
            return this;
        }

        public ExclusionGroupAssignmentTarget build() {
            ExclusionGroupAssignmentTarget _x = new ExclusionGroupAssignmentTarget();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.exclusionGroupAssignmentTarget";
            _x.deviceAndAppManagementAssignmentFilterId = deviceAndAppManagementAssignmentFilterId;
            _x.deviceAndAppManagementAssignmentFilterType = deviceAndAppManagementAssignmentFilterType;
            _x.groupId = groupId;
            return _x;
        }
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ExclusionGroupAssignmentTarget[");
        b.append("deviceAndAppManagementAssignmentFilterId=");
        b.append(this.deviceAndAppManagementAssignmentFilterId);
        b.append(", ");
        b.append("deviceAndAppManagementAssignmentFilterType=");
        b.append(this.deviceAndAppManagementAssignmentFilterType);
        b.append(", ");
        b.append("groupId=");
        b.append(this.groupId);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/ExclusionGroupAssignmentTarget.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;

import odata.msgraph.client.beta.enums.DeviceAndAppManagementAssignmentFilterType;


/**
 * <i>“Represents a group that should be excluded from an assignment.”</i>
 */@JsonPropertyOrder({
    "@odata.type"})
@JsonInclude(Include.NON_NULL)
public class ExclusionGroupAssignmentTarget extends GroupAssignmentTarget implements ODataType {

    protected ExclusionGroupAssignmentTarget() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.exclusionGroupAssignmentTarget";
    }

    public ExclusionGroupAssignmentTarget withUnmappedField(String name, Object value) {
        ExclusionGroupAssignmentTarget _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderExclusionGroupAssignmentTarget() {
        return new Builder();
    }

    public static final class Builder {
        private String deviceAndAppManagementAssignmentFilterId;
        private DeviceAndAppManagementAssignmentFilterType deviceAndAppManagementAssignmentFilterType;
        private String groupId;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder deviceAndAppManagementAssignmentFilterId(String deviceAndAppManagementAssignmentFilterId) {
            this.deviceAndAppManagementAssignmentFilterId = deviceAndAppManagementAssignmentFilterId;
            this.changedFields = changedFields.add("deviceAndAppManagementAssignmentFilterId");
            return this;
        }

        public Builder deviceAndAppManagementAssignmentFilterType(DeviceAndAppManagementAssignmentFilterType deviceAndAppManagementAssignmentFilterType) {
            this.deviceAndAppManagementAssignmentFilterType = deviceAndAppManagementAssignmentFilterType;
            this.changedFields = changedFields.add("deviceAndAppManagementAssignmentFilterType");
            return this;
        }

        public Builder groupId(String groupId) {
            this.groupId = groupId;
            this.changedFields = changedFields.add("groupId");
            return this;
        }

        public ExclusionGroupAssignmentTarget build() {
            ExclusionGroupAssignmentTarget _x = new ExclusionGroupAssignmentTarget();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.exclusionGroupAssignmentTarget";
            _x.deviceAndAppManagementAssignmentFilterId = deviceAndAppManagementAssignmentFilterId;
            _x.deviceAndAppManagementAssignmentFilterType = deviceAndAppManagementAssignmentFilterType;
            _x.groupId = groupId;
            return _x;
        }
    }

    private ExclusionGroupAssignmentTarget _copy() {
        ExclusionGroupAssignmentTarget _x = new ExclusionGroupAssignmentTarget();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.deviceAndAppManagementAssignmentFilterId = deviceAndAppManagementAssignmentFilterId;
        _x.deviceAndAppManagementAssignmentFilterType = deviceAndAppManagementAssignmentFilterType;
        _x.groupId = groupId;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ExclusionGroupAssignmentTarget[");
        b.append("deviceAndAppManagementAssignmentFilterId=");
        b.append(this.deviceAndAppManagementAssignmentFilterId);
        b.append(", ");
        b.append("deviceAndAppManagementAssignmentFilterType=");
        b.append(this.deviceAndAppManagementAssignmentFilterType);
        b.append(", ");
        b.append("groupId=");
        b.append(this.groupId);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
